package org.example.model;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

public class NewsAgency {

	private static final NewsAgency instance = new NewsAgency();

	public static NewsAgency getInstance() {
		return instance;
	}

	private final List<NewsItem> items = new ArrayList<>();
	private int lastId = 0;

	private NewsAgency() {
		items.add(new NewsItem(++lastId, LocalDate.now(), "Today is a good day."));
	}

	public List<NewsItem> getNews() {
		return items;
	}

	public List<NewsItem> searchNews(String keyword) {
		return items.stream().filter(item -> item.getText().toLowerCase().contains(keyword.toLowerCase())).toList();
	}

	public void postNews(NewsItem item) throws InvalidNewsException {
		if (!item.getText().matches("[A-Za-z0-9,. ]+")) throw new InvalidNewsException();
		item.setId(++lastId);
		if (item.getDate() == null) item.setDate(LocalDate.now());
		items.add(item);
	}

	public void deleteNews(int id) throws NewsNotFoundException {
		if (!items.removeIf(item -> item.getId() == id)) {
			throw new NewsNotFoundException();
		}
	}
}
