package org.example;

import io.restassured.RestAssured;
import org.example.model.NewsItem;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

import java.time.LocalDate;

import static io.restassured.http.ContentType.JSON;
import static org.hamcrest.Matchers.hasItem;
import static org.hamcrest.Matchers.notNullValue;

public class NewsIntegrationTest {

	@BeforeAll
	public static void setBaseURI() {
		RestAssured.baseURI = "http://localhost:8080/api";
	}

	@Test
	public void getNews() {
		RestAssured.given().accept(JSON)
				.when().get("/news")
				.then().statusCode(200).body("text", hasItem("Today is a good day."));
	}

	@Test
	public void postNews() {
		NewsItem newsItem = new NewsItem(null, LocalDate.now(), "No news are good news.");
		RestAssured.given().accept(JSON).contentType(JSON).body(newsItem)
				.when().post("/news")
				.then().statusCode(201).body("id", notNullValue());
	}

	@Test
	public void postNewsWithInvalidText() {
		NewsItem newsItem = new NewsItem(null, LocalDate.now(), "<script>");
		RestAssured.given().contentType(JSON).body(newsItem)
				.when().post("/news")
				.then().statusCode(400);
	}

	@Test
	public void deleteNews() {
		RestAssured.given().auth().preemptive().basic("admin", "12345")
				.when().delete("/news/1")
				.then().statusCode(204);
	}

	@Test
	public void deleteNewsWithoutAuthentication() {
		RestAssured.given().accept(JSON)
				.when().delete("/news/1")
				.then().statusCode(401);
	}
}
